@@ -95,7 +95,7 @@ class libuv_build_ext(build_ext):
     libuv_dir      = os.path.join('deps', 'libuv')
     libuv_repo     = 'https://github.com/joyent/libuv.git'
     libuv_branch   = 'v0.10'
-    libuv_revision = '851a662'
+    libuv_revision = '983fa68'
     libuv_patches  = []
 
     user_options = build_ext.user_options
@@ -159,7 +159,7 @@ class libuv_build_ext(build_ext):
         def build_libuv():
             cflags = '-fPIC'
             env = os.environ.copy()
-            env['CFLAGS'] = ' '.join(x for x in (cflags, env.get('CFLAGS', None)) if x)
+            env['CFLAGS'] = ' '.join(x for x in (cflags, env.get('CFLAGS', None), env.get('ARCHFLAGS', None)) if x)
             log.info('Building libuv...')
             if win32_msvc:
                 prepare_windows_env(env)
